@@ -10,7 +10,7 @@ export default function PropertyCheckbox(_ref) {
 
   return React.createElement(
     'div',
-    { style: { marginBottom: "3px" } },
+    { className: 'PropertyCheckbox', style: { marginBottom: "3px" } },
     React.createElement(
       'div',
       { style: { display: "inline-block", width: "30%" } },
