@@ -5,8 +5,6 @@ function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in ob
 import React, { PropTypes, Component } from 'react';
 import FormTextInput from './form-text-input';
 
-//TODO Check if min and max are not defined
-
 export default function FormNumberInput(_ref) {
   var onChange = _ref.onChange,
       rest = _objectWithoutProperties(_ref, ['onChange']);
@@ -14,7 +12,10 @@ export default function FormNumberInput(_ref) {
   var onChangeCustom = function onChangeCustom(event) {
     var value = event.target.value;
 
-    if (value <= rest.min || value >= rest.max) {
+    rest.min = rest.min ? parseFloat(rest.min) : -Infinity;
+    rest.max = rest.max ? parseFloat(rest.max) : Infinity;
+
+    if (parseFloat(value) <= (parseFloat(rest.min) || -Infinity) || parseFloat(value) >= (parseFloat(rest.max) || Infinity)) {
       event.target.value = rest.min;
       onChange(event);
       event.target.select();
@@ -23,13 +24,13 @@ export default function FormNumberInput(_ref) {
         onChange(event);
       } else {
         if (value === '-') {
-          if (rest.min <= 0) {
-            event.target.value = 0;
+          if (rest.min == 0) {
+            event.target.value = '0';
             event.target.select();
-            onChange(event);
           }
+          onChange(event);
         } else if (value === '0' || value === '') {
-          event.target.value = rest.min;
+          event.target.value = rest.min > 0 ? rest.min : '0';
           onChange(event);
           event.target.select();
         }
