@@ -5,7 +5,7 @@ export default function PropertyCheckbox({value, onUpdate, configs}) {
   value = value === true;
 
   return (
-    <div style={{marginBottom: "3px"}}>
+    <div className="PropertyCheckbox" style={{marginBottom: "3px"}}>
       <div style={{display: "inline-block", width: "30%"}}>
         <FormLabel>{configs.label}</FormLabel>
       </div>
